/*
 * exportscreen.h - Screen for exporting to USB drives
 * Copyright (C) 2024  Alexander Rosenberg
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version. See the LICENSE file for more information.
 */
#ifndef INCLUDED_EXPORTSCREEN_H
#define INCLUDED_EXPORTSCREEN_H

#include "screen.h"
#include "../drive.h"

#include <pthread.h>
#include <time.h>
#include <stdatomic.h>
#include <sqlite3.h>

typedef struct {
    Screen parent;
    enum {
        EXPORT_SCREEN_FORMAT = 0,
        EXPORT_SCREEN_DRIVE,
        EXPORT_SCREEN_CONFIRM_NEWFS,
        EXPORT_SCREEN_WRITE_NEWFS,
        EXPORT_SCREEN_MOUNTING,
        EXPORT_SCREEN_CONFIRM_OVERWRITE,
        EXPORT_SCREEN_WRITING,
        EXPORT_SCREEN_DONE,
        EXPORT_SCREEN_CONFIRM_CANCEL,
        EXPORT_SCREEN_CANCELED,
        EXPORT_SCREEN_FAILED,
        EXPORT_SCREEN_NO_DRIVES,
    } stage;
    enum {
        EXPORT_FORMAT_SQLITE = 0,
        EXPORT_FORMAT_CSV,
        EXPORT_NFORMAT,
    };
    int format;
    bool need_redraw;

    bool read_drives;
    Drive *drives;
    size_t ndrive;
    size_t cur_drive;
    int confirm_state;
    bool bg_inited;
    pthread_t backgroud_oper;
    int working_char;
    time_t last_char_change;
    bool need_overwrite;
    sqlite3 *db_cache;
    int last_cancel_stage;
} ExportScreen;

ExportScreen *export_screen_new(void);

#endif
