/*
 * timesel.h - Time selector
 * Copyright (C) 2024  Alexander Rosenberg
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version. See the LICENSE file for more information.
 */
#ifndef INCLUDED_TIMESEL_H
#define INCLUDED_TIMESEL_H

#include "../util.h"
#include "screen.h"
#include "datesel.h"

typedef struct {
    DateSelection *ds;
    enum {
        TS_STAGE_HOUR,
        TS_STAGE_MINUTE,
        TS_STAGE_SECOND
    } stage;
    int hour;
    int minute;
    bool do_second;
    int second;
} TimeSelection;

typedef enum {
    TIME_SEL_BACK,
    TIME_SEL_CONTINUE,
    TIME_SEL_DONE,
    TIME_SEL_ERROR,
} TimeSelState;

/*
 * Initialize the TimeSelection TS. Optionally, get the year, month, and day,
 * and limits from DS.
 */
void time_sel_init(TimeSelection *ts, DateSelection *ds, bool do_second);

/*
 * Dispatch (process input and draw) the TimeSelection TS according to STATE.
 * Return: the current state of the selection (back, continue, done).
 */
TimeSelState time_sel_dispatch(TimeSelection *ts, SensorState *state,
                               const char *label);

/*
 * Reset TS back to 00:00.
 */
void time_sel_reset(TimeSelection *ts);

#endif
